<?php

namespace Drupal\quickchat_sync\Controller;

use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\OpenModalDialogCommand;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Form\FormBuilder;

/**
 * Controller to provide a route so we can insert a modal form in an Ajax call.
 */
class ModalFormController extends ControllerBase {

  /**
   * The form builder.
   *
   * @var \Drupal\Core\Form\FormBuilder
   */
  protected $formBuilder;

  /**
   * The ModalFormController constructor.
   *
   * @param \Drupal\Core\Form\FormBuilder $formBuilder
   *   The form builder.
   */
  public function __construct(FormBuilder $formBuilder) {
    $this->formBuilder = $formBuilder;
  }

  /**
   * {@inheritdoc}
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The Drupal service container.
   *
   * @return static
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('form_builder')
    );
  }

  /**
   * Callback for opening the modal form.
   */
  public function openModalForm($model_name, $operation) {
    $response = new AjaxResponse();
    $title = 'Are you sure you want to ' . $operation . ' the model?';

    if ($operation == 'update') {
      $title .= ' This will overwrite the knowledge base at Quickchat AI.';
      $operation = 'update_knowledge_base';
    }

    // Get the modal form using the form builder.
    $modal_form = $this->formBuilder->getForm('Drupal\quickchat_sync\Form\ModalForm', $model_name, $operation);

    // Add an AJAX command to open a modal dialog with the form as the content.
    $response->addCommand(new OpenModalDialogCommand(
      $title,
      $modal_form,
      ['width' => '900']
    ));

    return $response;
  }

}
